@@ -1,4 +1,4 @@
-test_that("typical workflow",{
+{
   ## ========================================================
   library(D4TAlink.light)
   ## ========================================================
@@ -24,8 +24,10 @@ test_that("typical workflow",{
     ## create an Excel report in first task
     d <- list(letters=data.frame(a=LETTERS,b=letters,c=1:length(letters)),
               other=data.frame(a=1:3,b=11:13))
-    file <- saveReportXls(d,task,"table")
-    if(FALSE) utils::browseURL(file)
+    if(FALSE) {
+      file <- saveReportXls(d,task,"table")
+      if(FALSE) utils::browseURL(file)
+    }
     ## ============================
     ## save an R object report in first task
     saveBinary(d,task,"data")
@@ -75,4 +77,4 @@ test_that("typical workflow",{
     unlink(getTaskRoot(),recursive=TRUE)
   }
   ## ========================================================
-})
+}
